@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.pubsublite_v1.types import common
@@ -51,11 +53,11 @@ class InitialCommitCursorRequest(proto.Message):
             range [0, topic.num_partitions).
     """
 
-    subscription = proto.Field(
+    subscription: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    partition = proto.Field(
+    partition: int = proto.Field(
         proto.INT64,
         number=2,
     )
@@ -74,7 +76,7 @@ class SequencedCommitCursorRequest(proto.Message):
             The new value for the committed cursor.
     """
 
-    cursor = proto.Field(
+    cursor: common.Cursor = proto.Field(
         proto.MESSAGE,
         number=1,
         message=common.Cursor,
@@ -93,7 +95,7 @@ class SequencedCommitCursorResponse(proto.Message):
             in the order that they are received.
     """
 
-    acknowledged_commits = proto.Field(
+    acknowledged_commits: int = proto.Field(
         proto.INT64,
         number=1,
     )
@@ -120,13 +122,13 @@ class StreamingCommitCursorRequest(proto.Message):
             This field is a member of `oneof`_ ``request``.
     """
 
-    initial = proto.Field(
+    initial: "InitialCommitCursorRequest" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="request",
         message="InitialCommitCursorRequest",
     )
-    commit = proto.Field(
+    commit: "SequencedCommitCursorRequest" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="request",
@@ -155,13 +157,13 @@ class StreamingCommitCursorResponse(proto.Message):
             This field is a member of `oneof`_ ``request``.
     """
 
-    initial = proto.Field(
+    initial: "InitialCommitCursorResponse" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="request",
         message="InitialCommitCursorResponse",
     )
-    commit = proto.Field(
+    commit: "SequencedCommitCursorResponse" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="request",
@@ -184,15 +186,15 @@ class CommitCursorRequest(proto.Message):
             The new value for the committed cursor.
     """
 
-    subscription = proto.Field(
+    subscription: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    partition = proto.Field(
+    partition: int = proto.Field(
         proto.INT64,
         number=2,
     )
-    cursor = proto.Field(
+    cursor: common.Cursor = proto.Field(
         proto.MESSAGE,
         number=3,
         message=common.Cursor,
@@ -226,15 +228,15 @@ class ListPartitionCursorsRequest(proto.Message):
             the page token.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -250,11 +252,11 @@ class PartitionCursor(proto.Message):
             The value of the cursor.
     """
 
-    partition = proto.Field(
+    partition: int = proto.Field(
         proto.INT64,
         number=1,
     )
-    cursor = proto.Field(
+    cursor: common.Cursor = proto.Field(
         proto.MESSAGE,
         number=2,
         message=common.Cursor,
@@ -265,7 +267,7 @@ class ListPartitionCursorsResponse(proto.Message):
     r"""Response for ListPartitionCursors
 
     Attributes:
-        partition_cursors (Sequence[google.cloud.pubsublite_v1.types.PartitionCursor]):
+        partition_cursors (MutableSequence[google.cloud.pubsublite_v1.types.PartitionCursor]):
             The partition cursors from this request.
         next_page_token (str):
             A token, which can be sent as ``page_token`` to retrieve the
@@ -277,12 +279,12 @@ class ListPartitionCursorsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    partition_cursors = proto.RepeatedField(
+    partition_cursors: MutableSequence["PartitionCursor"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="PartitionCursor",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
